% Auto-generated chapter 30 for ibnmajah
% Hadiths in this chapter: 65

\hadithdefcmd{ibnmajah}{3371}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، جَمِيعًا عَنْ رَاشِدٍ أَبِي مُحَمَّدٍ الْحِمَّانِيِّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ أَوْصَانِي خَلِيلِي ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَشْرَبِ الْخَمْرَ فَإِنَّهَا مِفْتَاحُ كُلِّ شَرٍّ ‏"‏ ‏.‏\hadithno{3371}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Darda’ said:‘My close friend (ﷺ) advised me: ‘Do not drink wine, for it is the key to all evils.’”}}
\hadithdefcmd{ibnmajah}{3372}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مُنِيرُ بْنُ الزُّبَيْرِ، أَنَّهُ سَمِعَ عُبَادَةَ بْنَ نُسَىٍّ، يَقُولُ سَمِعْتُ خَبَّابَ بْنَ الأَرَتِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ إِيَّاكَ وَالْخَمْرَ فَإِنَّ خَطِيئَتَهَا تَفْرَعُ الْخَطَايَا كَمَا أَنَّ شَجَرَتَهَا تَفْرَعُ الشَّجَرَ ‏"‏ ‏.‏\hadithno{3372}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Ubadah bin Samit said:“I heard Khabbab bin Arat narrating that the Messenger of Allah (ﷺ) said: ‘Beware of wine! For its sins overwhelm other sins, just as the grapevine overwhelms other trees.’”}}
\hadithdefcmd{ibnmajah}{3373}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا لَمْ يَشْرَبْهَا فِي الآخِرَةِ إِلاَّ أَنْ يَتُوبَ ‏"‏ ‏.‏\hadithno{3373}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Whoever drinks wine in this world, he will not drink it in the Hereafter, unless he repents.”}}
\hadithdefcmd{ibnmajah}{3374}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي زَيْدُ بْنُ وَاقِدٍ، أَنَّ خَالِدَ بْنَ عَبْدِ اللَّهِ بْنِ حُسَيْنٍ، حَدَّثَهُ قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا لَمْ يَشْرَبْهَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3374}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Whoever drinks wine in this world, he will not drink it in the Hereafter.”}}
\hadithdefcmd{ibnmajah}{3375}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ بْنِ الأَصْبَهَانِيِّ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مُدْمِنُ الْخَمْرِ كَعَابِدِ وَثَنٍ ‏"‏ ‏.‏\hadithno{3375}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The one who is addicted to wine is like one who worships idols.”}}
\hadithdefcmd{ibnmajah}{3376}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ عُتْبَةَ، حَدَّثَنِي يُونُسُ بْنُ مَيْسَرَةَ بْنِ حَلْبَسٍ، عَنْ أَبِي إِدْرِيسَ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ مُدْمِنُ خَمْرٍ ‏"‏ ‏.‏\hadithno{3376}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Darda’ that the Prophet (ﷺ) said:“No one who is addicted to wine will enter Paradise.”}}
\hadithdefcmd{ibnmajah}{3377}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنِ ابْنِ الدَّيْلَمِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ شَرِبَ الْخَمْرَ وَسَكِرَ لَمْ تُقْبَلْ لَهُ صَلاَةٌ أَرْبَعِينَ صَبَاحًا وَإِنْ مَاتَ دَخَلَ النَّارَ فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ وَإِنْ عَادَ فَشَرِبَ فَسَكِرَ لَمْ تُقْبَلْ لَهُ صَلاَةٌ أَرْبَعِينَ صَبَاحًا فَإِنْ مَاتَ دَخَلَ النَّارَ فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ وَإِنْ عَادَ فَشَرِبَ فَسَكِرَ لَمْ تُقْبَلْ لَهُ صَلاَةٌ أَرْبَعِينَ صَبَاحًا فَإِنْ مَاتَ دَخَلَ النَّارَ فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ وَإِنْ عَادَ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يَسْقِيَهُ مِنْ رَدْغَةِ الْخَبَالِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا رَدْغَةُ الْخَبَالِ قَالَ ‏"‏ عُصَارَةُ أَهْلِ النَّارِ ‏"‏ ‏.‏\hadithno{3377}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“Whoever drinks wine and gets drunk, his prayer will not be accepted for forty days, and if he dies he will enter Hell, but if he repents, Allah will accept his repentance. If he drinks wine again and gets drunk, his prayer will not be accepted for forty days, and if he dies he will enter Hell, but if he repents, Allah will accept his repentance. If he drinks wine again and gets drunk, his prayer will not be accepted for forty days, and if he dies he will enter Hell, but if he repents Allah will accept his repentance. But if he does it again, then Allah will most certainly make him drink of the mire of the puss or sweat on the Day of Resurrection.” They said: “O Messenger of Allah, what is the mire of the pus or sweat? He said: “The drippings of the people of Hell.”}}
\hadithdefcmd{ibnmajah}{3378}{حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ اللَّهِ الْيَمَامِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا أَبُو كَثِيرٍ السُّحَيْمِيُّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْخَمْرُ مِنْ هَاتَيْنِ الشَّجَرَتَيْنِ النَّخْلَةِ وَالْعِنَبَةِ ‏"‏ ‏.‏\hadithno{3378}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Wine comes from these two trees: The date palm and the grapevine.”}}
\hadithdefcmd{ibnmajah}{3379}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ خَالِدَ بْنَ كَثِيرٍ الْهَمْدَانِيَّ، حَدَّثَهُ أَنَّ السَّرِيَّ بْنَ إِسْمَاعِيلَ حَدَّثَهُ أَنَّ الشَّعْبِيَّ حَدَّثَهُ أَنَّهُ، سَمِعَ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِنَ الْحِنْطَةِ خَمْرًا وَمِنَ الشَّعِيرِ خَمْرًا وَمِنَ الزَّبِيبِ خَمْرًا وَمِنَ التَّمْرِ خَمْرًا وَمِنَ الْعَسَلِ خَمْرًا ‏"‏ ‏.‏\hadithno{3379}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Nu’man bin Bashir that the Messenger of Allah (ﷺ) said:“From wheat comes wine, from barley comes wine, from raisins comes wine, from dates comes wine and from honey comes wine.”}}
\hadithdefcmd{ibnmajah}{3380}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ الْغَافِقِيِّ، وَأَبِي، طُعْمَةَ مَوْلاَهُمْ أَنَّهُمَا سَمِعَا ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لُعِنَتِ الْخَمْرُ عَلَى عَشَرَةِ أَوْجُهٍ بِعَيْنِهَا وَعَاصِرِهَا وَمُعْتَصِرِهَا وَبَائِعِهَا وَمُبْتَاعِهَا وَحَامِلِهَا وَالْمَحْمُولَةِ إِلَيْهِ وَآكِلِ ثَمَنِهَا وَشَارِبِهَا وَسَاقِيهَا ‏"‏ ‏.‏\hadithno{3380}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Wine is cursed from ten angles: The wine itself, the one who squeezes (the grapes etc), the one for whom it is squeezed, the one who sells it, the one who buys it, the one who carries it, the one to whom it is carried, the one who consumes its price, the one who drinks it and the one who pours it.”}}
\hadithdefcmd{ibnmajah}{3381}{حَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدِ بْنِ يَزِيدَ بْنِ إِبْرَاهِيمَ التُّسْتَرِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ شَبِيبٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، - أَوْ حَدَّثَنِي أَنَسٌ، - قَالَ لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْخَمْرِ عَشَرَةً عَاصِرَهَا وَمُعْتَصِرَهَا وَالْمَعْصُورَةَ لَهُ وَحَامِلَهَا وَالْمَحْمُولَةَ لَهُ وَبَائِعَهَا وَالْمُبْتَاعَةَ لَهُ وَسَاقِيَهَا وَالْمُسْتَقَاةَ لَهُ ‏"‏ ‏.‏ حَتَّى عَدَّ عَشَرَةً مِنْ هَذَا الضَّرْبِ ‏.‏\hadithno{3381}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Anas said:“The Messenger of Allah (ﷺ) cursed ten with regard to wine: The one who squeezes (the grapes etc.), the one who asks for it to be squeezed, the one for whom it is squeezed, the one who carries it, the one to whom it is carried, the one who sells it, the one for whom it is brought, the one who pours it, the one for whom it is poured, until he counted ten like this.”}}
\hadithdefcmd{ibnmajah}{3382}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتِ الآيَاتُ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي الرِّبَا خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَحَرَّمَ التِّجَارَةَ فِي الْخَمْرِ ‏.‏\hadithno{3382}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“When the Verses at the end of Surat Al-Baqarah concerning usury were revealed, the Messenger of Allah(ﷺ) went out and forbade dealing in wine.”}}
\hadithdefcmd{ibnmajah}{3383}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَلَغَ عُمَرَ أَنَّ سَمُرَةَ، بَاعَ خَمْرًا فَقَالَ قَاتَلَ اللَّهُ سَمُرَةَ أَلَمْ يَعْلَمْ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ حُرِّمَتْ عَلَيْهِمُ الشُّحُومُ فَجَمَلُوهَا فَبَاعُوهَا ‏"‏ ‏.‏\hadithno{3383}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Abbas said:Umar heard that Samurah had sold some wine, and he said: “May Allah ruin Samurah! Does he not know that the Messenger of Allah (ﷺ) said: ‘May Allah curse the Jews, for animal fat was forbidden to them, so they melted it down and sold it.’”}}
\hadithdefcmd{ibnmajah}{3384}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ عَبْدِ الْقُدُّوسِ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَذْهَبُ اللَّيَالِي وَالأَيَّامُ حَتَّى تَشْرَبَ طَائِفَةٌ مِنْ أُمَّتِي الْخَمْرَ يُسَمُّونَهَا بِغَيْرِ اسْمِهَا ‏"‏ ‏.‏\hadithno{3384}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Umamah Al-Bahili that the Messenger of Allah (ﷺ) said:“Night and day will not cease until a group among my nation drinks wine, calling it by some other name.”}}
\hadithdefcmd{ibnmajah}{3385}{حَدَّثَنَا الْحُسَيْنُ بْنُ أَبِي السَّرِيِّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا سَعْدُ بْنُ أَوْسٍ الْعَبْسِيُّ، عَنْ بِلاَلِ بْنِ يَحْيَى الْعَبْسِيِّ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنِ ابْنِ مُحَيْرِيزٍ، عَنْ ثَابِتِ بْنِ السِّمْطِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَشْرَبُ نَاسٌ مِنْ أُمَّتِي الْخَمْرَ بِاسْمٍ يُسَمُّونَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{3385}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Ubadah bin Samit that the Messenger of Allah (ﷺ) said:“People among my nation will drink wine, under some other name that they will give it.”}}
\hadithdefcmd{ibnmajah}{3386}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، تَبْلُغُ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ ‏"‏ ‏.‏\hadithno{3386}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah, narrating it from the Prophet (ﷺ):“Every drink that causes intoxication is unlawful.”}}
\hadithdefcmd{ibnmajah}{3387}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا يَحْيَى بْنُ الْحَارِثِ الذِّمَارِيُّ، سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{3387}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Salim bin ‘Abdullah bin ‘Umar narrated that his father said:“The Messenger of Allah (ﷺ) said: ‘Every intoxicant is unlawful.’”}}
\hadithdefcmd{ibnmajah}{3388}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ أَيُّوبَ بْنِ هَانِئٍ، عَنْ مَسْرُوقٍ، عَنِ ابْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏ قَالَ ابْنُ مَاجَهْ هَذَا حَدِيثُ الْمِصْرِيِّينَ ‏.‏\hadithno{3388}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Mas’ud that the Messenger of Allah (ﷺ) said:“Every intoxicant is unlawful.”}}
\hadithdefcmd{ibnmajah}{3389}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا خَالِدُ بْنُ حَيَّانَ، عَنْ سُلَيْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ الزِّبْرِقَانِ، عَنْ يَعْلَى بْنِ شَدَّادِ بْنِ أَوْسٍ، سَمِعْتُ مُعَاوِيَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ عَلَى كُلِّ مُؤْمِنٍ ‏"‏ ‏.‏ وَهَذَا حَدِيثُ الرَّقِّيِّينَ ‏.‏\hadithno{3389}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mu’awiyah said:“I heard the Messenger of Allah (ﷺ) say: ‘Every intoxicant is unlawful for every believer.’”}}
\hadithdefcmd{ibnmajah}{3390}{حَدَّثَنَا سَهْلٌ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ، عَنْ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ مُسْكِرٍ خَمْرٌ وَكُلُّ خَمْرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{3390}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Every intoxicant is Khamr (wine) and every Khamr is unlawful.”}}
\hadithdefcmd{ibnmajah}{3391}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{3391}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Messenger of Allah (ﷺ) said:“Every intoxicant is unlawful.”}}
\hadithdefcmd{ibnmajah}{3392}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا أَبُو يَحْيَى، زَكَرِيَّا بْنُ مَنْظُورٍ عَنْ أَبِي حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ وَمَا أَسْكَرَ كَثِيرُهُ فَقَلِيلُهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{3392}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“Every intoxicant is unlawful and whatever causes intoxication in large amounts, a small amount of it is (also) unlawful.”}}
\hadithdefcmd{ibnmajah}{3393}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنِي دَاوُدُ بْنُ بَكْرٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا أَسْكَرَ كَثِيرُهُ فَقَلِيلُهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{3393}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“Whatever causes intoxication in large amounts, a small amount of it is (also) unlawful.”}}
\hadithdefcmd{ibnmajah}{3394}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا أَسْكَرَ كَثِيرُهُ فَقَلِيلُهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{3394}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“Whatever causes intoxication in large amounts a small amount of it is (also) unlawful.”}}
\hadithdefcmd{ibnmajah}{3395}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُنْبَذَ التَّمْرُ وَالزَّبِيبُ جَمِيعًا وَنَهَى أَنْ يُنْبَذَ الْبُسْرُ وَالرُّطَبُ جَمِيعًا ‏.‏ قَالَ اللَّيْثُ بْنُ سَعْدٍ حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ الْمَكِّيُّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مِثْلَهُ ‏.‏\hadithno{3395}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) forbade making Nabidh* with dates and raisins together, or with unripe dates and fresh dates together.” Another chain reports the same}}
\hadithdefcmd{ibnmajah}{3396}{حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ اللَّهِ الْيَمَامِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ أَبِي كَثِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَنْبِذُوا التَّمْرَ وَالْبُسْرَ جَمِيعًا وَانْبِذُوا كُلَّ وَاحِدٍ مِنْهُمَا عَلَى حِدَتِهِ ‏"‏ ‏.‏\hadithno{3396}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Do not make Nabidh with dried dates and unripe dates together, make Nabidh with each of them on its own.”}}
\hadithdefcmd{ibnmajah}{3397}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ تَجْمَعُوا بَيْنَ الرُّطَبِ وَالزَّهْوِ وَلاَ بَيْنَ الزَّبِيبِ وَالتَّمْرِ وَانْبِذُوا كُلَّ وَاحِدٍ مِنْهُمَا عَلَى حِدَتِهِ ‏"‏ ‏.‏\hadithno{3397}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin Abu Qatadah, from his father, that he heard the Messenger of Allah (ﷺ) say:“Do not combine fresh dates and unripe dates, or raisins and dates; rather make Nabidh with each one of them on its own.”}}
\hadithdefcmd{ibnmajah}{3398}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، قَالاَ حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، حَدَّثَتْنَا بَنَانَةُ بِنْتُ يَزِيدَ الْعَبْشَمِيَّةُ، عَنْ عَائِشَةَ، قَالَتْ كُنَّا نَنْبِذُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سِقَاءٍ فَنَأْخُذُ قَبْضَةً مِنْ تَمْرٍ أَوْ قَبْضَةً مِنْ زَبِيبٍ فَنَطْرَحُهَا فِيهِ ثُمَّ نَصُبُّ عَلَيْهِ الْمَاءَ فَنَنْبِذُهُ غُدْوَةً فَيَشْرَبُهُ عَشِيَّةً وَنَنْبِذُهُ عَشِيَّةً فَيَشْرَبُهُ غُدْوَةً ‏.‏ وَقَالَ أَبُو مُعَاوِيَةَ نَهَارًا فَيَشْرَبُهُ لَيْلاً أَوْ لَيْلاً فَيَشْرَبُهُ نَهَارًا ‏.‏\hadithno{3398}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“We used to make Nabidh for the Messenger of Allah (ﷺ) in a water skin. We would take a handful of dates or a handful of raisins, and put them in it, then pour water over it. We would make that in the morning and he would drink it in the evening, or we would make it in the evening and he would drink it in the morning.”}}
\hadithdefcmd{ibnmajah}{3399}{حَدَّثَنَا أَبُو كُرَيْبٍ، عَنْ إِسْمَاعِيلَ بْنِ صَبِيحٍ، عَنْ أَبِي إِسْرَائِيلَ، عَنْ أَبِي عُمَرَ الْبَهْرَانِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ يُنْبَذُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَيَشْرَبُهُ يَوْمَهُ ذَلِكَ وَالْغَدَ وَالْيَوْمَ الثَّالِثَ فَإِنْ بَقِيَ مِنْهُ شَىْءٌ أَهْرَاقَهُ أَوْ أَمَرَ بِهِ فَأُهْرِيقَ ‏.‏\hadithno{3399}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Nabidh would be made for the Messenger of Allah (ﷺ) and he would drink it on the same day, or the next day, or the third day, and if there was any left he would throw it away or give orders that it was to be thrown away.”}}
\hadithdefcmd{ibnmajah}{3400}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ يُنْبَذُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي تَوْرٍ مِنْ حِجَارَةٍ ‏.‏\hadithno{3400}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“Nabidh would be made for the Messenger of Allah (ﷺ) in a vessel of stone.”}}
\hadithdefcmd{ibnmajah}{3401}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُنْبَذَ فِي النَّقِيرِ وَالْمُزَفَّتِ وَالدُّبَّاءِ وَالْحَنْتَمَةِ وَقَالَ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{3401}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade making Nabidh in Naqir, Muzaffat, Dubba’, and Hantamah. And he said: ‘Every intoxicant is unlawful.”}}
\hadithdefcmd{ibnmajah}{3402}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُنْبَذَ فِي الْمُزَفَّتِ وَالْقَرْعِ ‏.‏\hadithno{3402}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade making Nabidh in Muzaffat or a gourd.”}}
\hadithdefcmd{ibnmajah}{3403}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبِي، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الشُّرْبِ فِي الْحَنْتَمِ وَالدُّبَّاءِ وَالنَّقِيرِ ‏.‏\hadithno{3403}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) forbade drinking from Hantam, Dubba’ and Naqir}}
\hadithdefcmd{ibnmajah}{3404}{حَدَّثَنَا أَبُو بَكْرٍ، وَالْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالاَ حَدَّثَنَا شَبَابَةُ، عَنْ شُعْبَةَ، عَنْ بُكَيْرِ بْنِ عَطَاءٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَعْمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الدُّبَّاءِ وَالْحَنْتَمِ ‏.‏\hadithno{3404}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Abdur-Rahman bin Ya’mar said:“The Messenger of Allah (ﷺ) forbade Dubba’ and Hantam.”}}
\hadithdefcmd{ibnmajah}{3405}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، عَنْ شَرِيكٍ، عَنْ سِمَاكٍ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُنْتُ نَهَيْتُكُمْ عَنِ الأَوْعِيَةِ فَانْتَبِذُوا فِيهِ وَاجْتَنِبُوا كُلَّ مُسْكِرٍ ‏"‏ ‏.‏\hadithno{3405}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Buraidah from his father that the Prophet (ﷺ) said:“I used to forbid you to use certain vessels, but now make Nabidh in them, but avoid all intoxicants.”}}
\hadithdefcmd{ibnmajah}{3406}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ أَيُّوبَ بْنِ هَانِئٍ، عَنْ مَسْرُوقِ بْنِ الأَجْدَعِ، عَنِ ابْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنْ نَبِيذِ الأَوْعِيَةِ أَلاَ وَإِنَّ وِعَاءً لاَ يُحَرِّمُ شَيْئًا كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{3406}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Mas’ud that the Messenger of Allah (ﷺ) said:“I used to forbid you from making Nabidh in certain vessels, but a vessel does not make something unlawful. All intoxicants are unlawful.”}}
\hadithdefcmd{ibnmajah}{3407}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، حَدَّثَتْنِي رُمَيْثَةُ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ أَتَعْجِزُ إِحْدَاكُنَّ أَنْ تَتَّخِذَ كُلَّ عَامٍ مِنْ جِلْدِ أُضْحِيَّتِهَا سِقَاءً ثُمَّ قَالَتْ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُنْبَذَ فِي الْجَرِّ وَفِي كَذَا وَفِي كَذَا إِلاَّ الْخَلَّ ‏.‏\hadithno{3407}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“Is anyone of you incapable of taking a water skin from the skin of her sacrifice each year?” Then she said: “The Messenger of Allah (ﷺ) forbade making Nabidh in (earthenware) jars, and in such and such, and such and such, except for vinegar.”}}
\hadithdefcmd{ibnmajah}{3408}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الْخَطْمِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُنْبَذَ فِي الْجِرَارِ ‏.‏\hadithno{3408}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade making Nabidh in (earthenware) jars.”}}
\hadithdefcmd{ibnmajah}{3409}{حَدَّثَنَا مُجَاهِدُ بْنُ مُوسَى، حَدَّثَنَا الْوَلِيدُ، عَنْ صَدَقَةَ أَبِي مُعَاوِيَةَ، عَنْ زَيْدِ بْنِ وَاقِدٍ، عَنْ خَالِدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِنَبِيذِ جَرٍّ يَنِشُّ فَقَالَ ‏ "‏ اضْرِبْ بِهَذَا الْحَائِطَ فَإِنَّ هَذَا شَرَابُ مَنْ لاَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ ‏"‏ ‏.‏\hadithno{3409}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“Some Nabidh from an (earthenware) jar was brought to the Messenger of Allah (ﷺ) and it was bubbling. He said: ‘Throw this against the wall, for this is the drink of one who does not believe in Allah and the Last Day.’”}}
\hadithdefcmd{ibnmajah}{3410}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ غَطُّوا الإِنَاءَ وَأَوْكُوا السِّقَاءَ وَأَطْفِئُوا السِّرَاجَ وَأَغْلِقُوا الْبَابَ فَإِنَّ الشَّيْطَانَ لاَ يَحُلُّ سِقَاءً وَلاَ يَفْتَحُ بَابًا وَلاَ يَكْشِفُ إِنَاءً فَإِنْ لَمْ يَجِدْ أَحَدُكُمْ إِلاَّ أَنْ يَعْرُضَ عَلَى إِنَائِهِ عُودًا وَيَذْكُرَ اسْمَ اللَّهِ فَلْيَفْعَلْ فَإِنَّ الْفُوَيْسِقَةَ تُضْرِمُ عَلَى أَهْلِ الْبَيْتِ بَيْتَهُمْ ‏"‏ ‏.‏\hadithno{3410}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“Cover your vessels, tie your water skins, extinguish your lamps and lock your doors, for Satan does not untie a water skin, open a door or uncover a vessel. If a person cannot find anything but a stick with which to cover his vessel and mention the Name of Allah, then let him do so. And the mouse could set fire to the house with its people inside.”}}
\hadithdefcmd{ibnmajah}{3411}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ بِتَغْطِيَةِ الإِنَاءِ وَإِيكَاءِ السِّقَاءِ وَإِكْفَاءِ الإِنَاءِ ‏"‏ ‏.‏\hadithno{3411}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) commanded us to cover our vessels, tie up our water skins and turn over our vessels.”}}
\hadithdefcmd{ibnmajah}{3412}{حَدَّثَنَا عِصْمَةُ بْنُ الْفَضْلِ، حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ بْنِ أَبِي حَفْصَةَ، حَدَّثَنَا حَرِيشُ بْنُ خِرِّيتٍ، أَنْبَأَنَا ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَصْنَعُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثَلاَثَةَ آنِيَةٍ مِنَ اللَّيْلِ مُخَمَّرَةً إِنَاءً لِطَهُورِهِ وَإِنَاءً لِسِوَاكِهِ وَإِنَاءً لِشَرَابِهِ ‏.‏\hadithno{3412}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“I used to prepare three covered vessels for the Messenger of Allah (ﷺ) at night: A vessel for his water for purification, a vessel for his tooth stick and a vessel for his drink.”}}
\hadithdefcmd{ibnmajah}{3413}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الَّذِي يَشْرَبُ فِي إِنَاءِ الْفِضَّةِ إِنَّمَا يُجَرْجِرُ فِي بَطْنِهِ نَارَ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{3413}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah (ﷺ) said:“The one who drinks from a silver vessel is swallowing Hell-fire into his belly.”}}
\hadithdefcmd{ibnmajah}{3414}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ حُذَيْفَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الشُّرْبِ فِي آنِيَةِ الذَّهَبِ وَالْفِضَّةِ وَقَالَ ‏ "‏ هِيَ لَهُمْ فِي الدُّنْيَا وَهِيَ لَكُمْ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3414}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hudhaifah said:“The Messenger of Allah (ﷺ) forbade drinking from vessels of gold and silver. He said: “They are for them in this world and for you in the Hereafter.’”}}
\hadithdefcmd{ibnmajah}{3415}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ نَافِعٍ، عَنِ امْرَأَةِ ابْنِ عُمَرَ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ شَرِبَ فِي إِنَاءِ فِضَّةٍ فَكَأَنَّمَا يُجَرْجِرُ فِي بَطْنِهِ نَارَ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{3415}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“Whoever drinks from a silver vessel, it is as if he is swallowing Hell-fire into his belly.”}}
\hadithdefcmd{ibnmajah}{3416}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ الأَنْصَارِيُّ، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسٍ، أَنَّهُ كَانَ يَتَنَفَّسُ فِي الإِنَاءِ ثَلاَثًا وَزَعَمَ أَنَسٌ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَتَنَفَّسُ فِي الإِنَاءِ ثَلاَثًا ‏.‏\hadithno{3416}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that he used to drink from a vessel in three draughts, and Anas said that the Messenger of Allah (ﷺ) used to drink from a vessel in three draughts}}
\hadithdefcmd{ibnmajah}{3417}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا رِشْدِينُ بْنُ كُرَيْبٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ شَرِبَ فَتَنَفَّسَ فِيهِ مَرَّتَيْنِ ‏.‏\hadithno{3417}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) drank, and took two breaths while doing so}}
\hadithdefcmd{ibnmajah}{3418}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ اخْتِنَاثِ الأَسْقِيَةِ أَنْ يُشْرَبَ مِنْ أَفْوَاهِهَا ‏.‏\hadithno{3418}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) forbade tipping up water skins in order to drink from their mouths.”}}
\hadithdefcmd{ibnmajah}{3419}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنْ سَلَمَةَ بْنِ وَهْرَامَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ اخْتِنَاثِ الأَسْقِيَةِ وَإِنَّ رَجُلاً بَعْدَمَا نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ ذَلِكَ قَامَ مِنَ اللَّيْلِ إِلَى سِقَاءٍ فَاخْتَنَثَهُ فَخَرَجَتْ عَلَيْهِ مِنْهُ حَيَّةٌ ‏.‏\hadithno{3419}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) forbade tipping up water skins. After the Messenger of Allah (ﷺ) had forbidden that, a man got up at night and tipped up a water skin, and a snake fell out of it onto him.”}}
\hadithdefcmd{ibnmajah}{3420}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الشُّرْبِ مِنْ فِي السِّقَاءِ ‏.‏\hadithno{3420}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade drinking (directly) from the mouth of a water skin.”}}
\hadithdefcmd{ibnmajah}{3421}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُشْرَبَ مِنْ فَمِ السِّقَاءِ ‏.‏\hadithno{3421}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) forbade drinking (directly) from the mouth of a water skin.”}}
\hadithdefcmd{ibnmajah}{3422}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَقَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ مِنْ زَمْزَمَ فَشَرِبَ قَائِمًا ‏.‏ فَذَكَرْتُ ذَلِكَ لِعِكْرِمَةَ فَحَلَفَ بِاللَّهِ مَا فَعَلَ ‏.‏\hadithno{3422}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{‘Asim narrated from Sha’bi, from Ibn ‘Abbas who said:“I drew water from Zamzam for the Prophet (ﷺ) and he drank standing up.”}}
\hadithdefcmd{ibnmajah}{3423}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَزِيدَ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ جَدَّةٍ، لَهُ يُقَالُ لَهَا كَبْشَةُ الأَنْصَارِيَّةُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ دَخَلَ عَلَيْهَا وَعِنْدَهَا قِرْبَةٌ مُعَلَّقَةٌ فَشَرِبَ مِنْهَا وَهُوَ قَائِمٌ فَقَطَعَتْ فَمَ الْقِرْبَةِ تَبْتَغِي بَرَكَةَ مَوْضِعِ فِي رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3423}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Abi ‘Amrah, from a grandmother of his who was called Kabshah Al-Ansariyyah, that the Messenger of Allah (ﷺ) entered upon her, and there was a water skin hanging there. He drank from it while standing, and she cut off the mouth of the water skin, seeking the blessing of the place where the mouth of the Messenger of Allah (ﷺ) had been}}
\hadithdefcmd{ibnmajah}{3424}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنِ الشُّرْبِ قَائِمًا ‏.‏\hadithno{3424}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) forbade drinking while standing up}}
\hadithdefcmd{ibnmajah}{3425}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أُتِيَ بِلَبَنٍ قَدْ شِيبَ بِمَاءٍ وَعَنْ يَمِينِهِ أَعْرَابِيٌّ وَعَنْ يَسَارِهِ أَبُو بَكْرٍ فَشَرِبَ ثُمَّ أَعْطَى الأَعْرَابِيَّ وَقَالَ ‏ "‏ الأَيْمَنُ فَالأَيْمَنُ ‏"‏ ‏.‏\hadithno{3425}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) was brought some milk mixed with water. On his right there was a Bedouin and on his left was Abu Bakr. He drank some, then he gave it to the Bedouin and said:“Pass it around to the right.”}}
\hadithdefcmd{ibnmajah}{3426}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُتِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِلَبَنٍ وَعَنْ يَمِينِهِ ابْنُ عَبَّاسٍ وَعَنْ يَسَارِهِ خَالِدُ بْنُ الْوَلِيدِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لاِبْنِ عَبَّاسٍ ‏ "‏ أَتَأْذَنُ لِي أَنْ أَسْقِيَ خَالِدًا ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ مَا أُحِبُّ أَنْ أُوثِرَ بِسُؤْرِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى نَفْسِي أَحَدًا ‏.‏ فَأَخَذَ ابْنُ عَبَّاسٍ فَشَرِبَ وَشَرِبَ خَالِدٌ ‏.‏\hadithno{3426}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) was brought some milk. On his right was Ibn ‘Abbas and on his left was Khalid bin Walid. The Messenger of Allah (ﷺ) said to Ibn ‘Abbas: ‘Will you permit me to give Khalid to drink?’ Ibn ‘Abbas said: ‘I would not like to give preference to anyone over myself when it comes to the leftover drink of the Messenger of Allah (ﷺ). So Ibn ‘Abbas took it and drank some, then Khalid drank some.”}}
\hadithdefcmd{ibnmajah}{3427}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ مُحَمَّدٍ، عَنِ الْحَارِثِ بْنِ أَبِي ذُبَابٍ، عَنْ عَمِّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا شَرِبَ أَحَدُكُمْ فَلاَ يَتَنَفَّسْ فِي الإِنَاءِ فَإِذَا أَرَادَ أَنْ يَعُودَ فَلْيُنَحِّ الإِنَاءَ ثُمَّ لْيَعُدْ إِنْ كَانَ يُرِيدُ ‏"‏ ‏.‏\hadithno{3427}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When anyone of you drinks, let him not breathe into the vessel. If he wants to continue drinking, let him move the vessel away (in order to breathe) then bring it back, if he wants.”}}
\hadithdefcmd{ibnmajah}{3428}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ التَّنَفُّسِ فِي الإِنَاءِ ‏.‏\hadithno{3428}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) forbade breathing into the vessel.”}}
\hadithdefcmd{ibnmajah}{3429}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُنْفَخَ فِي الإِنَاءِ ‏.‏\hadithno{3429}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) forbade blowing into the vessel.”}}
\hadithdefcmd{ibnmajah}{3430}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ عَبْدِ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ شَرِيكٍ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمْ يَكُنْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنْفُخُ فِي الشَّرَابِ ‏.‏\hadithno{3430}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) did not blow into his drinks.”}}
\hadithdefcmd{ibnmajah}{3431}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ مُسْلِمِ بْنِ عَبْدِ اللَّهِ، عَنْ زِيَادِ بْنِ عَبْدِ اللَّهِ، عَنْ عَاصِمِ بْنِ مُحَمَّدِ بْنِ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ نَهَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَشْرَبَ عَلَى بُطُونِنَا وَهُوَ الْكَرْعُ وَنَهَانَا أَنْ نَغْتَرِفَ بِالْيَدِ الْوَاحِدَةِ وَقَالَ ‏ "‏ لاَ يَلَغْ أَحَدُكُمْ كَمَا يَلَغُ الْكَلْبُ وَلاَ يَشْرَبْ بِالْيَدِ الْوَاحِدَةِ كَمَا يَشْرَبُ الْقَوْمُ الَّذِينَ سَخِطَ اللَّهُ عَلَيْهِمْ وَلاَ يَشْرَبْ بِاللَّيْلِ مِنْ إِنَاءٍ حَتَّى يُحَرِّكَهُ إِلاَّ أَنْ يَكُونَ إِنَاءً مُخَمَّرًا وَمَنْ شَرِبَ بِيَدِهِ وَهُوَ يَقْدِرُ عَلَى إِنَاءٍ يُرِيدُ التَّوَاضُعَ كَتَبَ اللَّهُ لَهُ بِعَدَدِ أَصَابِعِهِ حَسَنَاتٍ وَهُوَ إِنَاءُ عِيسَى ابْنِ مَرْيَمَ عَلَيْهِمَا السَّلاَمُ إِذْ طَرَحَ الْقَدَحَ فَقَالَ أُفٍّ هَذَا مَعَ الدُّنْيَا ‏"‏ ‏.‏\hadithno{3431}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Asim bin Muhammad bin Zaid bin ‘Abdullah, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) forbade us to drink while (lying) on our bellies, lapping up water, and he forbade us to drink from one hand only. He said: ‘None of you should lap up water as a dog does, and he should not drink water from one hand as the people with whom Allah is angry do, and he should not drink from a vessel at night without stirring it first, unless the vessel was covered. Whoever drinks from his hand when he is able to drink from a vessel, with the intention of humility, Allah will record good deeds equivalent to the number of fingers for him. It (i.e., the hand) is the vessel of ‘Eisa bin Maryam, (as) when he threw away the cup and said: ‘Ugh! That belongs to this world.’”}}
\hadithdefcmd{ibnmajah}{3432}{حَدَّثَنَا أَحْمَدُ بْنُ مَنْصُورٍ أَبُو بَكْرٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى رَجُلٍ مِنَ الأَنْصَارِ وَهُوَ يُحَوِّلُ الْمَاءَ فِي حَائِطِهِ فَقَالَ لَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنْ كَانَ عِنْدَكَ مَاءٌ بَاتَ فِي شَنٍّ فَاسْقِنَا وَإِلاَّ كَرَعْنَا ‏"‏ ‏.‏ قَالَ عِنْدِي مَاءٌ بَاتَ فِي شَنٍّ ‏.‏ فَانْطَلَقَ وَانْطَلَقْنَا مَعَهُ إِلَى الْعَرِيشِ فَحَلَبَ لَهُ شَاةً عَلَى مَاءٍ بَاتَ فِي شَنٍّ فَشَرِبَ ثُمَّ فَعَلَ مِثْلَ ذَلِكَ بِصَاحِبِهِ الَّذِي مَعَهُ ‏.‏\hadithno{3432}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) entered upon a man among the Ansar when he was watering his garden. The Messenger of Allah (ﷺ) said to him: ‘If you have any water that has been kept overnight in a water skin, then give us some to drink, otherwise we will drink by putting out mouths in the basin.’ He said: ‘I have water that has been kept in a water skin. So he went and we went with him, to the shelter, where he milked a sheep for him and (mixed it with) the water that had been kept overnight in a water skin. He drank from it, then he did likewise for his Companion who was with him.”}}
\hadithdefcmd{ibnmajah}{3433}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ لَيْثٍ، عَنْ سَعِيدِ بْنِ عَامِرٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَرَرْنَا عَلَى بِرْكَةٍ فَجَعَلْنَا نَكْرَعُ فِيهَا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَكْرَعُوا وَلَكِنِ اغْسِلُوا أَيْدِيَكُمْ ثُمَّ اشْرَبُوا فِيهَا فَإِنَّهُ لَيْسَ إِنَاءٌ أَطْيَبَ مِنَ الْيَدِ ‏"‏ ‏.‏\hadithno{3433}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“We passed by a pond and we started to lap up water from it. The Messenger of Allah (ﷺ) said: ‘Do not lap up the water, rather wash your hands then drink from them, for there is no better vessel than the hand.’”}}
\hadithdefcmd{ibnmajah}{3434}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَاقِي الْقَوْمِ آخِرُهُمْ شُرْبًا ‏"‏ ‏.‏\hadithno{3434}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ) said:“The oen who serves water to others should be the last one to drink from it.”}}
\hadithdefcmd{ibnmajah}{3435}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مِنْدَلُ بْنُ عَلِيٍّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَدَحٌ مِنْ قَوَارِيرَ يَشْرَبُ فِيهِ ‏.‏\hadithno{3435}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) had a glass cup from which he would drink.”}}
